# PromptGuard
PromptGuard enables applications to leverage the power of language models while preserving user privacy. This repo contains the PromptGuard Python library, which provides a simple interface for interacting with the PromptGuard Service. More information about PromptGuard can be found in the [documentation](https://promptguard.readthedocs.io/).

**API Stability:** This package is still in development. As such, its API may
change until it is sufficiently mature.

## Installation

The PromptGuard Python library can be installed via pip:

```bash
pip install promptguard
```

## Documentation
For a quickstart, technical overview, and API reference, see the [PromptGuard documentation](https://promptguard.readthedocs.io/).
